@@ -611,6 +611,51 @@ class LanguageLogstash(Language):
 known_languages['logstash'] = LanguageLogstash()
 
 
+class LanguageYAML(Language):
+    """YAML language rules."""
+
+    def format_version_no(self, version_parts):
+        return ".".join(version_parts)
+
+    def size_limit(self):
+        return 262144
+
+    def worth_checking(self, repo_path, repo_root):
+        if repo_path.endswith(b".yml") or repo_path.endswith(b".yaml"):
+            return {
+                'max_line_no': 20,
+                'max_expr_no': 1
+            }
+        else:
+            return False
+
+    def update_line(self, line, version, repo_path):
+        rgxps = self.re_yaml_rgxps
+        for rgxp in rgxps:
+            match = rgxp.search(line)
+            if match:
+                return match.group('before') + version + match.group('after')
+        return None
+
+    re_yaml_rgxps = [
+        re.compile(b'''
+        ^
+        (?P<before>
+             \\s* (?: module_ | package_ | )  version
+             \\s* : \\s*
+             (?P<quote2> ["']? )
+        )
+        (?P<version> \\d+(?:\\.\\d+)+  )
+        (?P<after>
+             \\s* (?P=quote2) \\s*
+        )
+        $''', re.VERBOSE),
+    ]
+
+
+known_languages['yaml'] = LanguageYAML()
+
+
 class LanguageCvsKeywords(Language):
     """
     Support for handling CVS keywords.
@@ -627,7 +672,7 @@ class LanguageCvsKeywords(Language):
         # detect last changes for all files and he is to commit them
         # after all)
         # …  self.current_rev.user()
-        self.current_fmt_user = shortuser(ui.username()) 
+        self.current_fmt_user = shortuser(ui.username())
 
     def size_limit(self):
         return 16384 * 1024
